#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Aug 21 10:01:30 2024

@author: pteysseyre
"""

This library countains all the functions needed to analyse in real time the measurements of an AWESOME antenna and to detect solar flares.
NOTE : This is a work in progress (2024/08/21). It is part of my PhD 

VERSIONS:
- 0.1.0
- 0.1.1: added flags and stored paths in functions (2024.08.21)
- 0.1.2: added detection of change points (2024.08.27)